@@ -23,7 +23,7 @@ namespace osl
      */
     class ProofTreeDepthDfpn
     {
-      class Table;
+      struct Table;
       boost::scoped_ptr<Table> table;
     public:
       explicit ProofTreeDepthDfpn(const DfpnTable& table);
