@@ -256,155 +256,19 @@ namespace osl
 	}
 	int openingValue() const 
 	{
-	  return (king_table_value[0] +
-		  piece_stand_value[0] +
-		  king25_effect_each[BLACK][0] + king25_effect_each[WHITE][0] +
-		  ptypex[0] +
-		  ptypey[0] +
- 		  rook_mobility[0] +
- 		  bishop_mobility[0] +
- 		  lance_mobility[0] +
-		  rook_effect[0] +
-		  bishop_effect[0] +
-		  piece_stand_combination[0] + 
-		  piece_stand_turn[turn][0] +
-		  rook_pawn[0] +
-		  pawn_drop[0] +
-		  piece_stand_y[0] +
-		  knight_check[0] +
-		  pawn_advance[0] +
-		  pawn_ptypeo[0] +
-		  promoted_minor_piece[0] +
-		  nosupport[0] +
-		  non_pawn_attacked[turn][0] +
-		  non_pawn_attacked_ptype[turn][0] +
-		  ptype_yy[0] +
-		  king3pieces[0] +
-		  bishop_head[0] +
-		  knight_head[0] +
-		  rook_promote_defense[0] +
-		  ptype_count_value[0] +
-		  lance_effect_piece[0] +
-		  ptype_y_pawn_y[0] +
-		  bishop_and_king[0] +
-		  piece_fork_turn[turn][0] +
-		  rook_silver_knight[0] +
-		  bishop_silver_knight[0] +
-		  recalculated_stage_value[0]);
+	  return stageValue()[0];
 	}
 	int midgameValue() const 
 	{
-	  return (king_table_value[1] +
-		  piece_stand_value[1] +
-		  king25_effect_each[BLACK][1] + king25_effect_each[WHITE][1] +
-		  ptypex[1] +
-		  ptypey[1] +
- 		  rook_mobility[1] +
- 		  bishop_mobility[1] +
- 		  lance_mobility[1] +
-		  rook_effect[1] +
-		  bishop_effect[1] +
-		  piece_stand_combination[1] + 
-		  piece_stand_turn[turn][1] +
-		  rook_pawn[1] +
-		  pawn_drop[1] +
-		  piece_stand_y[1] +
-		  knight_check[1] +
-		  pawn_advance[1] +
-		  pawn_ptypeo[1] +
-		  promoted_minor_piece[1] +
-		  nosupport[1] +
-		  non_pawn_attacked[turn][1] +
-		  non_pawn_attacked_ptype[turn][1] +
-		  ptype_yy[1] +
-		  king3pieces[1] +
-		  bishop_head[1] +
-		  knight_head[1] +
-		  rook_promote_defense[1] +
-		  ptype_count_value[1] +
-		  lance_effect_piece[1] +
-		  ptype_y_pawn_y[1] +
-		  bishop_and_king[1] +
-		  piece_fork_turn[turn][1] +
-		  rook_silver_knight[1] +
-		  bishop_silver_knight[1] +
-		  recalculated_stage_value[1]);
+	  return stageValue()[1];
 	}
 	int midgame2Value() const 
 	{
-	  return (king_table_value[2] +
-		  piece_stand_value[2] +
-		  king25_effect_each[BLACK][2] + king25_effect_each[WHITE][2] +
-		  ptypex[2] +
-		  ptypey[2] +
- 		  rook_mobility[2] +
- 		  bishop_mobility[2] +
- 		  lance_mobility[2] +
-		  rook_effect[2] +
-		  bishop_effect[2] +
-		  piece_stand_combination[2] + 
-		  piece_stand_turn[turn][2] +
-		  rook_pawn[2] +
-		  pawn_drop[2] +
-		  piece_stand_y[2] +
-		  knight_check[2] +
-		  pawn_advance[2] +
-		  pawn_ptypeo[2] +
-		  promoted_minor_piece[2] +
-		  nosupport[2] +
-		  non_pawn_attacked[turn][2] +
-		  non_pawn_attacked_ptype[turn][2] +
-		  ptype_yy[2] +
-		  king3pieces[2] +
-		  bishop_head[2] +
-		  knight_head[2] +
-		  rook_promote_defense[2] +
-		  ptype_count_value[2] +
-		  lance_effect_piece[2] +
-		  ptype_y_pawn_y[2] +
-		  bishop_and_king[2] +
-		  piece_fork_turn[turn][2] +
-		  rook_silver_knight[2] +
-		  bishop_silver_knight[2] +
-		  recalculated_stage_value[2]);
+	  return stageValue()[2];
 	}
 	int endgameValue() const 
 	{
-	  return (king_table_value[EndgameIndex] +
-		  piece_stand_value[EndgameIndex] +
-		  king25_effect_each[BLACK][EndgameIndex] + king25_effect_each[WHITE][EndgameIndex] +
-		  ptypex[EndgameIndex] +
-		  ptypey[EndgameIndex] +
- 		  rook_mobility[EndgameIndex] +
- 		  bishop_mobility[EndgameIndex] +
- 		  lance_mobility[EndgameIndex] +
-		  rook_effect[EndgameIndex] +
-		  bishop_effect[EndgameIndex] +
-		  piece_stand_combination[EndgameIndex] + 
-		  piece_stand_turn[turn][EndgameIndex] +
-		  rook_pawn[EndgameIndex] +
-		  pawn_drop[EndgameIndex] +
-		  piece_stand_y[EndgameIndex] +
-		  pawn_advance[EndgameIndex] +
-		  knight_check[EndgameIndex] +
-		  pawn_ptypeo[EndgameIndex] +
-		  promoted_minor_piece[EndgameIndex] +
-		  nosupport[EndgameIndex] +
-		  non_pawn_attacked[turn][EndgameIndex] +
-		  non_pawn_attacked_ptype[turn][EndgameIndex] +
-		  ptype_yy[EndgameIndex] +
-		  king3pieces[EndgameIndex] +
-		  bishop_head[EndgameIndex] +
-		  knight_head[EndgameIndex] +
-		  rook_promote_defense[EndgameIndex] +
-		  ptype_count_value[EndgameIndex] +
-		  lance_effect_piece[EndgameIndex] +
-		  ptype_y_pawn_y[EndgameIndex] +
-		  bishop_and_king[EndgameIndex] +
-		  piece_fork_turn[turn][EndgameIndex] +
-		  rook_silver_knight[EndgameIndex] +
-		  bishop_silver_knight[EndgameIndex] +
-		  recalculated_stage_value[EndgameIndex]);
+	  return stageValue()[EndgameIndex];
 	}
 	void invalidateCache() { cache=INVALID; }
 	static int progressIndependentValueAdjusted(int value, int progress,
@@ -540,6 +404,8 @@ namespace osl
 			    + progress.progress16(WHITE).value()); 
 	}
 	const Progress16 progress16() const { return progress.progress16(); }
+	int progressValue() const { return progress.progress(); }
+	int progressMax() const { return progress.maxProgress(); }
       public:
 	static int infty()
 	{
