@@ -1,7 +1,7 @@
 /* see.h
  */
-#ifndef _SEE_H
-#define _SEE_H
+#ifndef OSL_SEE_H
+#define OSL_SEE_H
 
 #include "osl/state/numEffectState.h"
 #include "osl/container/ptypeOSquareVector.h"
