@@ -11,7 +11,7 @@ namespace osl
   {
     class TimeKeeper
     {
-      class Stack;
+      struct Stack;
       boost::scoped_ptr<Stack> seconds;
     public:
       TimeKeeper();
