@@ -290,8 +290,8 @@ namespace osl
       if(isDrop()) return false;
       return ignoreUnpromote<P>(ptype(),from(),to());
     }
-    bool ignoreUnpromote(Player pl) const{
-      if(pl==BLACK) return ignoreUnpromote<BLACK>();
+    bool ignoreUnpromote() const{
+      if(player()==BLACK) return ignoreUnpromote<BLACK>();
       else return ignoreUnpromote<WHITE>();
     }
     /**
