@@ -15,7 +15,7 @@ namespace osl
     struct OpenCheck
     {
       static bool isMember(const NumEffectState& state, 
-			   Ptype ptype,Position from,Position to)
+			   Ptype ptype,Square from,Square to)
       {
 	return KingOpenMove<PlayerTraits<P>::opponent>::isMember
 	  (state,ptype,from,to);
