@@ -34,10 +34,12 @@ namespace osl
       struct NewProgressData
       {
 	CArray<MultiInt,2> non_pawn_ptype_attacked_pair_eval;
+	MultiInt promotion37_eval;
 	CArray<int, 2> progresses, attack5x5_progresses, stand_progresses,
 	  effect_progresses, defenses;
 	CArray<int, 2> rook, bishop, gold, silver, promoted,
 	  king_relative_attack, king_relative_defense, non_pawn_ptype_attacked_pair;
+	int pawn_facing, promotion37, piecestand7;
       };
       class NewProgress : private NewProgressData
       {
@@ -54,11 +56,19 @@ namespace osl
 	static CArray<int, 81*15*10> defense_relative;
 	static CArray<int, 4284> king_relative_weight;
 	static CArray<int, 262144> attacked_ptype_pair_weight;
+	static CArray<int, 10> pawn_facing_weight;
+	static CArray<int, 16> promotion37_weight;
+	static CArray<int, 56> piecestand7_weight;
 	static int max_progress;
 	void updatePieceKingRelativeBonus(const NumEffectState &state);
 	void updateNonPawnAttackedPtypePair(const NumEffectState& state);
 	template <Player Owner>
 	void updateNonPawnAttackedPtypePairOne(const NumEffectState& state);
+	void updatePawnFacing(const NumEffectState& state);
+	template <Player Attack>	
+	void promotion37One(const NumEffectState& state, int rank);
+	void updatePromotion37(const NumEffectState& state);
+	void updatePieceStand7(const NumEffectState& state);
 	template <Player P>
 	static void progressOne(const NumEffectState &state,
 				int &attack, int &defense);
@@ -195,7 +205,8 @@ namespace osl
 			      king_relative_defense[0] +
 			      king_relative_defense[1] +
 			      non_pawn_ptype_attacked_pair[0] +
-			      non_pawn_ptype_attacked_pair[1],
+			      non_pawn_ptype_attacked_pair[1] +
+			      pawn_facing + promotion37 + piecestand7,
 			      max_progress-ProgressScale), 0) / ProgressScale;
 	}
 	static int maxProgress() { return max_progress / ProgressScale; }
