@@ -1,5 +1,5 @@
-#ifndef _CSARECORD_H
-#define _CSARECORD_H
+#ifndef OSL_CSARECORD_H
+#define OSL_CSARECORD_H
 
 #include "osl/record/record.h"
 #include "osl/record/csa.h"
@@ -46,7 +46,7 @@ namespace osl
   using record::csa::CsaFile;
 
 } // namespace osl
-#endif /* _CSARECORD_H */
+#endif /* OSL_CSARECORD_H */
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
