@@ -65,10 +65,6 @@ namespace osl
       bool geZero() const{
 	return (v.l8&0x8080808080808080ull)==0x8080808080808080ull;
       }
-      bool gegtZero(bool notRejectSennichite) const{
-	if(notRejectSennichite) return gtZero();
-	else return geZero();
-      }
     };
     /**
      * 複数のmoveによる差分を分解したもの
@@ -151,15 +147,15 @@ namespace osl
        *   差分が相手一手分の時 -> move後に相手が可能ならtrue
        * 持ち駒渡しがない
        *   差分がない場合 -> 一手パス
-       *    notRootMoveの時は true (root以外ではそこでPASSできる)
-       *    そうでないときは false
+       *    isRootMoveの時は false(rootではPASSできない)
+       *    root以外では true
        *   差分が自分一手分の時 -> その手が2n手前に可能ならtrue
        *   差分が相手一手分の時 -> move後に相手が可能で
-       *    notRejectSennichiteの時は false (千日手の方がましな可能性がある)
-       *    そうでないときは true (有利だったら相手に千日手のチャンスを耐えない)
+       *    mayRejectSennichiteの時は true (有利だったら相手に千日手のチャンスを耐えない)
+       *    そうでないときは false (千日手の方がましな可能性がある)
        */
       template<Player P>
-      bool canReject(NumEffectState const& state,bool notRejectSennichite,bool notRootMove,Move lastMove,Move actualMove) const;
+      bool canReject(NumEffectState const& state,bool mayRejectSennichite,bool isRootMove,Move lastMove,Move actualMove) const;
     };
     std::ostream& operator<<(std::ostream&,OnBoardElement const&);
     std::ostream& operator<<(std::ostream&,StandElements const&);
@@ -171,13 +167,13 @@ namespace osl
        * P - 手番(mのplayer)の立場で判別
        * state - m を実行する前の状態
        * history - mを含まない過去の記録．
-       * curDepth - 探索開始からの深さ
+       * ply - 探索開始からの深さ
        * m - チェックする手
        * alpha - windowのPに取っての下限
        * checkCountOfAltP - 相手が連続王手の時にいくつ続いたか
        */
       template<Player P>
-      static bool probe(NumEffectState const& state,MoveStack const& history,int curDepth,Move const& m,int alpha, int checkCountOfAltP);
+      static bool probe(NumEffectState const& state,MoveStack const& history,int ply,Move const& m,int alpha, int checkCountOfAltP);
     };
   }
 }
