@@ -16,6 +16,7 @@ namespace osl
       virtual void newDepth(int depth);
       virtual void showPV(int depth, size_t node_count, double elapsed, int value, Move cur, const Move *first, const Move *last, 
 			  const bool *threatmate_first, const bool *threatmate_last);
+      virtual void showFailLow(int depth, size_t node_count, double elapsed, int value, Move cur);
       virtual void rootMove(Move cur);
       virtual void rootFirstMove(Move cur);
       virtual void timeInfo(size_t node_count, double elapsed);
@@ -23,6 +24,7 @@ namespace osl
       virtual void rootForcedMove(Move the_move);
       virtual void rootLossByCheckmate();
       virtual void depthFinishedNormally(int depth);
+      virtual void searchFinished();
     };
   }
   using search::SearchMonitor;
