@@ -68,6 +68,11 @@ namespace osl
       {
 	return pin_or_open[king]&piecesOnBoard(king);
       }
+      /** attack の駒で動くと開き王手になる可能性がある集合 */
+      const PieceMask checkShadow(Player attack) const
+      {
+	return pin_or_open[alt(attack)]&piecesOnBoard(attack);
+      }
       PieceMask pinOrOpen(Player king) const
       {
 	return pin_or_open[king];
