@@ -10,10 +10,10 @@ namespace osl
   {
     template 
     bool ImmediateCheckmate::
-    hasCheckmateMove<BLACK>(NumEffectState const&, King8Info, Position, Move&);
+    hasCheckmateMove<BLACK>(NumEffectState const&, King8Info, Square, Move&);
     template 
     bool osl::checkmate::ImmediateCheckmate::
-    hasCheckmateMove<WHITE>(NumEffectState const&, King8Info, Position, Move&);
+    hasCheckmateMove<WHITE>(NumEffectState const&, King8Info, Square, Move&);
 
     template 
     bool ImmediateCheckmate::
