@@ -10,6 +10,7 @@
 #include "osl/eval/ml/king8.h"
 #include "osl/eval/ml/progress.h"
 #include "osl/effect_util/pin.h"
+#include "osl/effect_util/effectUtil.tcc"
 #include "osl/misc/random.h"
 #include "osl/misc/binaryIO.h"
 #include "osl/oslConfig.h"
@@ -474,6 +475,8 @@ OpenMidEndingEval::doResetWeights(Reader& reader)
   read_count += setUpOne<RookSilverKnight>(reader);
   read_count += setUpOne<BishopSilverKnight>(reader);
   read_count += setUpOne<AttackMajorsInBase>(reader);
+  read_count += setUpOne<CheckShadowPtype>(reader);
+  read_count += setUpOne<Promotion37>(reader);
 
   initialized_flag = reader.failed() ? Zero : Loaded;
   if (initialized_flag != Loaded)
@@ -719,6 +722,8 @@ OpenMidEndingEval::OpenMidEndingEval(const NumEffectState &state, bool use_limit
   rook_silver_knight = RookSilverKnight::eval(state);
   bishop_silver_knight = BishopSilverKnight::eval(state);
   recalculated_stage_value += AttackMajorsInBase::eval(state);
+  recalculated_stage_value += CheckShadowPtype::eval(state);
+  recalculated_stage_value += Promotion37::eval(state);
   piece_fork_turn = SilverFork::eval(state, silver_drop);
   piece_fork_turn += BishopRookFork::eval(state, bishop_drop, rook_drop);
   piece_fork_turn += KnightFork::eval(state, knight_fork_squares, knight_drop);
@@ -1099,10 +1104,13 @@ OpenMidEndingEval::updateSub(const NumEffectState &new_state, Move last_move)
     bishop_silver_knight = BishopSilverKnight::eval(new_state);
   }
   recalculated_stage_value += AttackMajorsInBase::eval(new_state);
+  recalculated_stage_value += CheckShadowPtype::eval(new_state);
 #ifdef USE_TEST_PROGRESS
+  recalculated_stage_value += progress.rawData().promotion37_eval;
   recalculated_stage_value += progress.rawData().non_pawn_ptype_attacked_pair_eval[BLACK]
     + progress.rawData().non_pawn_ptype_attacked_pair_eval[WHITE];
 #else
+  recalculated_stage_value += Promotion37::eval(new_state);
   recalculated_stage_value += NonPawnAttackedPtypePair::eval(new_state);
 #endif
   piece_fork_turn = SilverFork::eval(new_state, silver_drop);
@@ -1490,6 +1498,18 @@ setRandom()
 }
 #endif
 
+#ifndef DFPNSTATONE
+namespace osl
+{
+  template void
+  EffectUtil::findThreat<osl::eval::ml::OpenMidEndingEval>(
+    const NumEffectState& state,
+    Square position,
+    PtypeO ptypeo,
+    PieceVector& out);
+}
+#endif
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
