@@ -2,8 +2,9 @@
 #include "osl/eval/pieceEval.tcc"
 #include "osl/eval/evalTraits.h"
 #include "osl/state/numEffectState.h"
+#include "osl/effect_util/effectUtil.tcc"
 #include "osl/pieceTable.h"
-#include <iostream>
+
 namespace osl
 {
   // explicit template instantiation
@@ -11,6 +12,16 @@ namespace osl
   (const NumEffectState&, Move);
   template int PieceEval::computeDiffAfterMove<WHITE>
   (const NumEffectState&, Move);
+
+#ifndef DFPNSTATONE
+#ifndef MINIMAL
+  template void
+  EffectUtil::findThreat<PieceEval>(const NumEffectState& state,
+				    Square position,
+				    PtypeO ptypeo,
+				    PieceVector& out);
+#endif
+#endif
 }
 
 osl::PieceEval::PieceEval(const NumEffectState& state)
@@ -85,6 +96,7 @@ void osl::eval::PtypeEvalTable::reset(const CArray<int,PTYPE_SIZE>& values)
   }
 }
 
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
