@@ -88,6 +88,7 @@ CsaClient::readAndProcessCommand()
 	logger->writeComment("unsafe king");
       else if (illegal_move == GameState::OTHER_INVALID)
 	logger->writeComment("other illegal move");
+      os << "%CHUDAN" << std::endl;
       throw EndGame();
     }
     const Sennichite result = pushMove(MoveWithComment(op_move), op_think_time);
@@ -156,7 +157,7 @@ CsaClient::processComputerMove(const MoveWithComment& selected,
   }
 
   os << record::csa::show(best_move, reserved);
-  if (show_move_with_comment && ! selected.moves.empty())
+  if (show_move_with_comment && (! selected.moves.empty() || selected.value != 0))
   {
     os << ",'* " << selected.value;
     BOOST_FOREACH(Move move, selected.moves)
