@@ -150,8 +150,10 @@ GameState::evalStack() const
 }
 
 void osl::game_playing::
-GameState::generateNotLosingMoves(MoveVector& normal_or_win_or_draw, 
-				  MoveVector& loss) const
+GameState::generateMoves(container::MoveVector& normal, 
+			 container::MoveVector& win, 
+			 container::MoveVector& draw, 
+			 container::MoveVector& loss) const
 {
   MoveVector all;
   LegalMoves::generate(state(), all);
@@ -163,9 +165,15 @@ GameState::generateNotLosingMoves(MoveVector& normal_or_win_or_draw,
     }
     const Sennichite result
       = counter().isSennichite(state(), m);
-    if (result.hasWinner()
-	&& result.winner() == alt(state().turn())) {
-      loss.push_back(m);
+    if (! result.isNormal()) {
+      if (! result.hasWinner())
+	draw.push_back(m);
+      else {
+	if (result.winner() == alt(state().turn()))
+	  loss.push_back(m);
+	else
+	  win.push_back(m);
+      }
       continue;
     } 
     copy.copyFrom(state());
@@ -177,10 +185,20 @@ GameState::generateNotLosingMoves(MoveVector& normal_or_win_or_draw,
 	continue;
       }
     }
-    normal_or_win_or_draw.push_back(m);
+    normal.push_back(m);
   }
 }
 
+void osl::game_playing::
+GameState::generateNotLosingMoves(MoveVector& normal_or_win_or_draw, 
+				  MoveVector& loss) const
+{
+  MoveVector win, draw;
+  generateMoves(normal_or_win_or_draw, win, draw, loss);
+  normal_or_win_or_draw.push_back(win.begin(), win.end());
+  normal_or_win_or_draw.push_back(draw.begin(), draw.end());
+}
+
 /* ------------------------------------------------------------------------- */
 // ;;; Local Variables:
 // ;;; mode:c++
