@@ -478,7 +478,7 @@ waitResult(Move last_move, search::TimeAssigned wait_for,
       if ((result = results->find(last_move))) {
 #ifndef GPSONE
 	if (wait_count == 0 && OslConfig::usiMode()) {
-	  search::UsiReporter::showPV(result->root_limit/200, result->node_count, result->elapsed,
+	  search::UsiReporter::showPV(std::cout, result->root_limit/200, result->node_count, result->elapsed,
 				      last_move.player() == BLACK ? -result->value : result->value,
 				      result->move, &*result->moves.begin(), &*result->moves.end(),
 				      true);
