@@ -260,6 +260,13 @@ const std::string osl::OslConfig::gpsusiConf()
   return home_directory + "/gpsusi.conf";
 }
 
+int osl::OslConfig::resignThreshold()
+{
+  static const int value = getenv("OSL_RESIGN_VALUE") 
+    ? atoi(getenv("OSL_RESIGN_VALUE")) : 0;
+  return (value > 0) ? value : 10000;
+}
+
 const std::string osl::OslConfig::makeTest()
 {
   std::string result;
