@@ -2,6 +2,7 @@
 #include "osl/eval/ml/weights.h"
 #include "osl/eval/ml/midgame.h"
 #include "osl/eval/ml/minorPiece.h"
+#include "osl/effect_util/additionalEffect.h"
 #include "osl/pieceStand.h"
 #include "osl/oslConfig.h"
 #include <boost/foreach.hpp>
@@ -42,6 +43,12 @@ osl::misc::CArray<int, 4284>
 osl::progress::ml::NewProgress::king_relative_weight;
 osl::CArray<int, 262144> 
 osl::progress::ml::NewProgress::attacked_ptype_pair_weight;
+osl::CArray<int, 10> 
+osl::progress::ml::NewProgress::pawn_facing_weight;
+osl::CArray<int, 16> 
+osl::progress::ml::NewProgress::promotion37_weight;
+osl::CArray<int, 56> 
+osl::progress::ml::NewProgress::piecestand7_weight;
 int osl::progress::ml::NewProgress::max_progress;
 bool osl::progress::ml::NewProgress::initialized_flag;
 
@@ -178,6 +185,30 @@ bool osl::progress::ml::NewProgress::setUp(const char *filename)
     attacked_ptype_pair_weight[i] = val;
     ++read_count;
   }
+  weights.resetDimension(10);
+  for (size_t i = 0; i < weights.dimension(); ++i)
+  {
+    int val;
+    is >> val;
+    pawn_facing_weight[i] = val;
+    ++read_count;
+  }
+  weights.resetDimension(16);
+  for (size_t i = 0; i < weights.dimension(); ++i)
+  {
+    int val;
+    is >> val;
+    promotion37_weight[i] = val;
+    ++read_count;
+  }
+  weights.resetDimension(56);
+  for (size_t i = 0; i < weights.dimension(); ++i)
+  {
+    int val;
+    is >> val;
+    piecestand7_weight[i] = val;
+    ++read_count;
+  }
   {
     int val;
     is >> val;
@@ -237,7 +268,9 @@ bool osl::progress::ml::NewProgress::setUp(const char *filename)
       attacked_ptype_pair_weight[eval::ml::NonPawnAttackedPtypePair::index2(j,i)]
 	= attacked_ptype_pair_weight[eval::ml::NonPawnAttackedPtypePair::index2(i,j)];
     }
-	      
+  // set sum of [1..i] into [i], keep [0] as is.
+  for (int i=2; i<10; ++i)
+    pawn_facing_weight[i] += pawn_facing_weight[i-1];
 
   initialized_flag = is;
   if (!initialized_flag)
@@ -416,8 +449,9 @@ updateNonPawnAttackedPtypePairOne(const NumEffectState& state)
   typedef eval::ml::NonPawnAttackedPtypePair feature_t;
   int result = 0;
   MultiInt result_eval;
-  for (size_t i=0; i+1<pieces.size(); ++i) {
+  for (size_t i=0; i<pieces.size(); ++i) {
     const int i0 = feature_t::index1(state, pieces[i]);
+    result += attacked_ptype_pair_weight[feature_t::index2(0,i0)];
     for (size_t j=i+1; j<pieces.size(); ++j) {
       const int i1 = feature_t::index1(state, pieces[j]);
       result += attacked_ptype_pair_weight[feature_t::index2(i0,i1)];
@@ -438,6 +472,77 @@ updateNonPawnAttackedPtypePair(const NumEffectState& state)
   updateNonPawnAttackedPtypePairOne<WHITE>(state);
 }
 
+void osl::progress::ml::NewProgress::
+updatePawnFacing(const NumEffectState& state)
+{
+  PieceMask attacked = state.effectedMask(WHITE) & state.piecesOnBoard(BLACK);
+  mask_t pawn = attacked.selectBit<PAWN>()
+    & ~(state.promotedPieces().getMask<PAWN>());
+  int count = 0;
+  while (pawn.any()) {
+    const Piece p(state.pieceOf(pawn.takeOneBit()+PtypeFuns<PAWN>::indexNum*32));
+    if (state.hasEffectByPtypeStrict<PAWN>(WHITE, p.square()))
+      ++count;
+  }
+  pawn_facing = pawn_facing_weight[count];
+}
+
+template <osl::Player P>
+void osl::progress::ml::
+NewProgress::promotion37One(const NumEffectState& state, int rank)
+{
+  typedef eval::ml::Promotion37 feature_t;
+  CArray<int,PTYPE_SIZE> count = {{ 0 }};
+  for (int x=1; x<=9; ++x) {
+    const Square target(x, rank);
+    if (! state[target].isEmpty())
+      continue;
+    int a = state.countEffect(P, target);
+    const int d = state.countEffect(alt(P), target);
+    if (a > 0 && a == d)
+      a += AdditionalEffect::hasEffect(state, target, P);
+    if (a < d)
+      continue;
+    const Ptype ptype = state.findCheapAttack(P, target).ptype();
+    if (isPiece(ptype) && ! isPromoted(ptype))
+      count[ptype]++;
+  }
+  for (int p=PTYPE_BASIC_MIN; p<=PTYPE_MAX; ++p) {
+    if (count[p] > 0) {
+      promotion37 += promotion37_weight[p];
+      promotion37_eval += feature_t::table[p]*playerToMul(P);
+    }
+    if (count[p] > 1) {
+      promotion37 += promotion37_weight[p-8]*(count[p]-1);
+      promotion37_eval += feature_t::table[p-8]*(playerToMul(P)*(count[p]-1));
+    }
+  }
+}
+
+void osl::progress::ml::NewProgress::
+updatePromotion37(const NumEffectState& state)
+{
+  promotion37 = 0;
+  promotion37_eval = MultiInt();
+  promotion37One<BLACK>(state, 3);
+  promotion37One<WHITE>(state, 7);
+}
+
+void osl::progress::ml::NewProgress::
+updatePieceStand7(const NumEffectState& state)
+{
+  piecestand7 = 0;
+  for (int z=0; z<2; ++z) {
+    CArray<int,7> stand = {{ 0 }};
+    int filled = 0;
+    BOOST_FOREACH(Ptype ptype, PieceStand::order)
+      if (state.hasPieceOnStand(indexToPlayer(z), ptype))
+	stand[filled++] = ptype-PTYPE_BASIC_MIN;
+    for (int i=0; i<std::min(7,filled+1); ++i)
+      piecestand7 += piecestand7_weight[stand[i] + 8*i];
+  }
+}
+
 osl::progress::ml::NewProgress::NewProgress(
   const NumEffectState &state)
 {
@@ -475,6 +580,9 @@ osl::progress::ml::NewProgress::NewProgress(
   }
   updatePieceKingRelativeBonus(state);
   updateNonPawnAttackedPtypePair(state);
+  updatePawnFacing(state);
+  updatePromotion37(state);
+  updatePieceStand7(state);
 }
 
 template<osl::Player P>
@@ -567,6 +675,9 @@ void osl::progress::ml::NewProgress::updateMain(
     }
   }
   updateNonPawnAttackedPtypePair(new_state);
+  updatePawnFacing(new_state);
+  updatePromotion37(new_state);
+  updatePieceStand7(new_state);
 }
 
 template<osl::Player P>
