@@ -4,7 +4,11 @@
 #include "osl/pieceStand.h"
 #include "osl/move.h"
 #include "osl/misc/carray.h"
+#ifndef _WIN32
 #include "osl/misc/iconvConvert.h"
+#else
+#include "osl/misc/characterEncodingConvertWin32.h"
+#endif
 #include <boost/foreach.hpp>
 #include <iostream>
 #include <string>
@@ -144,16 +148,16 @@ const osl::misc::CArray<std::string,32> osl::record::RussianCharacters::pieces =
 const osl::misc::CArray<std::string,10> osl::record::KIFCharacters::dan = 
   osl::record::StandardCharacters::dan;
 const osl::misc::CArray<std::string,10> osl::record::KIFCharacters::suji = 
-  {{"", " "+K_R1, " "+K_R2, " "+K_R3, " "+K_R4, " "+K_R5, " "+K_R6, " "+K_R7, " "+K_R8, " "+K_R9}};
+  {{"", " " K_R1, " " K_R2, " " K_R3, " " K_R4, " " K_R5, " " K_R6, " " K_R7, " " K_R8, " " K_R9}};
 const osl::misc::CArray<std::string,32> osl::record::KIFCharacters::pieces = 
   {{// WHITE
-    " "+K_NAKAGURO, "+E",
-    "v"+K_PPAWN, "v"+K_PLANCE, "v"+K_PKNIGHT, "v"+K_PSILVER, "v"+K_PBISHOP, "v"+K_PROOK,  "v"+K_KING, 
-    "v"+K_GOLD,  "v"+K_PAWN,   "v"+K_LANCE,   "v"+K_KNIGHT,  "v"+K_SILVER,  "v"+K_BISHOP, "v"+K_ROOK,
+    " " K_NAKAGURO, "+E",
+    "v" K_PPAWN, "v" K_PLANCE, "v" K_PKNIGHT, "v" K_PSILVER, "v" K_PBISHOP, "v" K_PROOK,  "v" K_KING, 
+    "v" K_GOLD,  "v" K_PAWN,   "v" K_LANCE,   "v" K_KNIGHT,  "v" K_SILVER,  "v" K_BISHOP, "v" K_ROOK,
     // BLACK
-    " "+K_NAKAGURO, "+E",
-    " "+K_PPAWN, " "+K_PLANCE, " "+K_PKNIGHT, " "+K_PSILVER, " "+K_PBISHOP, " "+K_PROOK,  " "+K_KING, 
-    " "+K_GOLD,  " "+K_PAWN,   " "+K_LANCE,   " "+K_KNIGHT,  " "+K_SILVER,  " "+K_BISHOP, " "+K_ROOK
+    " " K_NAKAGURO, "+E",
+    " " K_PPAWN, " " K_PLANCE, " " K_PKNIGHT, " " K_PSILVER, " " K_PBISHOP, " " K_PROOK,  " " K_KING, 
+    " " K_GOLD,  " " K_PAWN,   " " K_LANCE,   " " K_KNIGHT,  " " K_SILVER,  " " K_BISHOP, " " K_ROOK
   }};
 
 
@@ -181,12 +185,20 @@ void osl::record::KanjiPrint::
 print(const osl::state::SimpleState& state, 
       const osl::Move *last_move) const
 {
-  os << IconvConvert::eucToLang(K_WHITE_STAND) << " ";
+  os <<
+#ifndef _WIN32
+    IconvConvert::
+#endif
+    eucToLang(K_WHITE_STAND) << " ";
   BOOST_FOREACH(Ptype ptype, PieceStand::order)
   {
     const int count = state.countPiecesOnStand(WHITE, ptype);
     if (count)
-      os << IconvConvert::eucToLang(pieces->stand_kanji(newPtypeO(BLACK, ptype)))
+      os <<
+#ifndef _WIN32
+        IconvConvert::
+#endif
+        eucToLang(pieces->stand_kanji(newPtypeO(BLACK, ptype)))
 	 << count << " ";
   }
   os << std::endl;  
@@ -194,7 +206,11 @@ print(const osl::state::SimpleState& state,
   os << " ";
   for(int x=9;x>0;x--)
   {
-    os << IconvConvert::eucToLang(pieces->getSuji(x));
+    os <<
+#ifndef _WIN32
+      IconvConvert::
+#endif
+      eucToLang(pieces->getSuji(x));
   }
   os << std::endl;  
 
@@ -212,7 +228,10 @@ print(const osl::state::SimpleState& state,
     {
       const PtypeO ptypeo = state.pieceOnBoard(Square(x,y)).ptypeO();
       const std::string piece =
-	IconvConvert::eucToLang(pieces->kanji(ptypeo));
+#ifndef _WIN32
+	IconvConvert::
+#endif
+        eucToLang(pieces->kanji(ptypeo));
       if (last_move && 
           !last_move->isInvalid() && 
           last_move->to() == Square(x,y))
@@ -236,7 +255,12 @@ print(const osl::state::SimpleState& state,
       }
     }
     os << '|';  
-    os << IconvConvert::eucToLang(pieces->getDan(y));
+    os <<
+#ifndef _WIN32
+      IconvConvert::
+#endif
+      eucToLang(pieces->getDan(y));
+
     os << std::endl;
   }
 
@@ -248,12 +272,20 @@ print(const osl::state::SimpleState& state,
   os << "+" << std::endl;
 
   // 持ち駒の表示
-  os << IconvConvert::eucToLang(K_BLACK_STAND) << " ";
+  os <<
+#ifndef _WIN32
+    IconvConvert::
+#endif
+    eucToLang(K_BLACK_STAND) << " ";
   BOOST_FOREACH(Ptype ptype, PieceStand::order)
   {
     const int count = state.countPiecesOnStand(BLACK, ptype);
     if (count)
-      os << IconvConvert::eucToLang(pieces->stand_kanji(newPtypeO(BLACK, ptype)))
+      os <<
+#ifndef _WIN32
+        IconvConvert::
+#endif
+        eucToLang(pieces->stand_kanji(newPtypeO(BLACK, ptype)))
 	 << count << " ";
   }
   os << std::endl;  
