@@ -30,7 +30,7 @@ namespace osl
 
         if (line.empty() || line.at(0) == '*')
           return OK;
-        else if (line.size() > 10 && line.substr(0,10) == (K_KAISHI+K_NICHIJI+K_COLON))
+        else if (line.size() > 10 && line.substr(0,10) == (K_KAISHI K_NICHIJI K_COLON))
         {
           Record *record = rv.getRecord();
           std::string date_str(line.substr(10)); // this may or may not include HH:MM
@@ -46,27 +46,27 @@ namespace osl
           // you can check it date.is_special()
           return OK;
         }
-        else if (line.size() > 6 && line.substr(0,6) == (K_BLACK+K_COLON))
+        else if (line.size() > 6 && line.substr(0,6) == (K_BLACK K_COLON))
         {
           Record *record = rv.getRecord();
           const std::string player_name(line.substr(6));
           record->setPlayer(osl::BLACK, player_name);
           return OK;
         }
-        else if (line.size() > 6 && line.substr(0,6) == (K_WHITE+K_COLON))
+        else if (line.size() > 6 && line.substr(0,6) == (K_WHITE K_COLON))
         {
           Record *record = rv.getRecord();
           const std::string player_name(line.substr(6));
           record->setPlayer(osl::WHITE, player_name);
           return OK;
         }
-        else if (line.size() > 6 && line.substr(0,6) == (K_KISEN+K_COLON))
+        else if (line.size() > 6 && line.substr(0,6) == (K_KISEN K_COLON))
         {
           Record *record = rv.getRecord();
           record->setTounamentName(line.substr(6));
           return OK;
         }
-        else if (line.size() > 8 && line.substr(0,8) == (K_TEAIWARI+K_COLON))
+        else if (line.size() > 8 && line.substr(0,8) == (K_TEAIWARI K_COLON))
           return KOMAOCHI;
         else if (line.substr(0,2) != K_BLACK_SIGN && line.substr(0,2) != K_WHITE_SIGN)
           return OK;
@@ -319,21 +319,36 @@ const std::string osl::record::ki2::show(Move m, const NumEffectState& state,
 }
 
 const std::string osl::record::
-ki2::show(const Move *first, const Move *last, const NumEffectState& initial, Move prev)
+ki2::show(const Move *first, const Move *last,
+	  const char *threatmate_first, const char *threatmate_last,
+	  const NumEffectState& initial, Move prev)
 {
   if (first == last || first->isInvalid())
     return "";
   NumEffectState state(initial);
   std::string ret = show(*first, state, prev);
+  if (threatmate_first != threatmate_last
+      && *threatmate_first++)
+    ret += "(" K_TSUMERO ")";
   for (; first+1 != last; ++first) {
     if (first->isInvalid())
       break;
     state.makeMove(*first);
     ret += show(*(first+1), state, *first);
+    if (threatmate_first != threatmate_last
+	&& *threatmate_first++)
+      ret += "(" K_TSUMERO ")";
   }
   return ret;
 }
 
+const std::string osl::record::
+ki2::show(const Move *first, const Move *last, const NumEffectState& initial, Move prev)
+{
+  vector<char> threatmate(last-first, false);
+  return show(first, last, &*threatmate.begin(), &*threatmate.end(), initial, prev);
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
