@@ -1,8 +1,12 @@
 #include "osl/record/record.h"
 #include "osl/record/csaIOError.h"
+#include "osl/record/kanjiCode.h"
+#include "osl/misc/iconvConvert.h"
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/algorithm/string/split.hpp>
+#include <boost/algorithm/string/replace.hpp>
 #include <boost/lexical_cast.hpp>
+#include <boost/foreach.hpp>
 #include <stack>
 #include <iostream>
 
@@ -34,7 +38,17 @@ namespace record
   
   
   Record::Record(){ init(); }
-  
+  Record::Record(const SimpleState& initial, const vector<Move>& moves)
+  {
+    init();
+    NumEffectState copy(initial);
+    RecordVisitor visitor;
+    visitor.setState(&copy);
+    visitor.setRecord(this);
+    BOOST_FOREACH(Move move, moves) {
+      visitor.addMoveAndAdvance(move);
+    }
+  }  
   void Record::init(){
     version="";
     playerNames[0]=playerNames[1]="";
@@ -108,12 +122,27 @@ namespace record
     std::vector<std::string> values;
     boost::algorithm::split(values, date_str, boost::algorithm::is_any_of("/"));
     if (values.size() < 3) {
-      std::cerr << "ERROR: Invalid date format found: " << date_str << "\n";
+      std::cerr << "ERROR: Invalid date format found: "
+#ifndef MINIMAL
+		<< IconvConvert::eucToLang(date_str)
+#endif
+		<< "\n";
       return;
     } else if (values.size() > 3) {
-      std::cerr << "WARNING: Invalid date format found: " << date_str << "\n";
+      std::cerr << "WARNING: Invalid date format found: "
+#ifndef MINIMAL
+		<< IconvConvert::eucToLang(date_str)
+#endif
+		<< "\n";
       // go through
     }
+    BOOST_FOREACH(std::string& value, values) {
+      static const CArray<const char *,9> kanji = {{
+	  K_R1, K_R2, K_R3, K_R4, K_R5, K_R6, K_R7, K_R8, K_R9, 
+	}};
+      for (size_t i=0; i<kanji.size(); ++i)
+	boost::algorithm::replace_all(value, kanji[i], std::string(1, char('0'+i)));
+    }
     int year  = 0;
     int month = 0;
     int day   = 0;
@@ -122,11 +151,19 @@ namespace record
       month = boost::lexical_cast<int>(values[1]);
       if (month == 0) month = 1;
       if ("??" == values[2]) {
-        std::cerr << "WARNING: Invalid date format found: " << values[2] << "\n";
+        std::cerr << "WARNING: Invalid date format found: "
+#ifndef MINIMAL
+		  << IconvConvert::eucToLang(values[2])
+#endif
+		  << "\n";
         // go through
         day = 1;
       } else if (values[2].size() > 2) {
-        std::cerr << "WARNING: Invalid date format found: " << values[2] << "\n";
+        std::cerr << "WARNING: Invalid date format found: "
+#ifndef MINIMAL
+		  << IconvConvert::eucToLang(values[2])
+#endif
+		  << "\n";
         // go through
         day = boost::lexical_cast<int>(values[2].substr(0,2));
       } else {
@@ -136,10 +173,18 @@ namespace record
       start_date = boost::gregorian::date(year, month, day);
       assert(!start_date.is_special());
     } catch (boost::bad_lexical_cast& e) {
-      std::cerr << "Invalid date format found: " << date_str << "\n"
+      std::cerr << "Invalid date format found: "
+#ifndef MINIMAL
+		<< IconvConvert::eucToLang(date_str)
+#endif
+		<< "\n"
                 << e.what() << std::endl;
     } catch (boost::gregorian::bad_day_of_month& ebdm) {
-      std::cerr << "Bad day of month: " << date_str << "\n"
+      std::cerr << "Bad day of month: "
+#ifndef MINIMAL
+		<< IconvConvert::eucToLang(date_str)
+#endif
+		<< "\n"
                 << ebdm.what() << std::endl;
     }
     return;
