@@ -94,7 +94,18 @@ show(const SimpleState& state)
 const osl::Move osl::record::usi::
 strToMove(const std::string& str, const SimpleState& s)
 {
-  return psn::strToMove(str, s);
+  if (str == "win")
+    return Move::DeclareWin();
+  if (str == "pass")
+    return Move::PASS(s.turn());
+  if (str == "resign")
+    return Move::INVALID();
+  try {
+    return psn::strToMove(str, s);
+  }
+  catch (...) {
+    throw ParseError("usi::strToMove failed for " + str);
+  }
 }
 
 osl::PtypeO osl::record::usi::
