@@ -1260,7 +1260,8 @@ void osl::search::AlphaBeta2Tree<EvalT>::updateCheckmateCount()
 {
 #ifdef OSL_SMP
   if (shared) {
-    this->recorder.setCheckmateCount(shared->checkmateCount());
+    const size_t new_count = shared->checkmateCount();
+    this->recorder.setCheckmateCount(new_count);
     return;
   }
 #endif
@@ -2053,6 +2054,14 @@ finish:
       }
     }
   }
+#ifndef GPSONE
+  {
+    boost::mutex::scoped_lock lk(OslConfig::lock_io);
+    BOOST_FOREACH(const boost::shared_ptr<SearchMonitor>& monitor,
+		  this->monitors())
+      monitor->searchFinished();
+  }
+#endif
   return last_best_move;
 }
 
@@ -2075,9 +2084,7 @@ alphaBetaSearchRoot(Window window, MoveLogProb& best_move, int limit)
   setRoot(limit);
   assert(this->curDepth() == 0);
   this->node_type[this->curDepth()] = base_t::PvNode;
-#ifdef NEW_DFPN
   this->checkmate_searcher->setRootPlayer(P);
-#endif
 #ifdef OSL_SMP
   if (this->shared)
     this->shared->threadStart();
@@ -2340,6 +2347,17 @@ alphaBetaSearchRoot(Window window, MoveLogProb& best_move, int limit)
 	{
 	  if (this->table->isVerbose())
 	    this->showFailLow(result, moves[0].move());
+#ifndef GPSONE
+	  if (this->hasMonitor() && !this->prediction_for_speculative_search) {
+	    const double scale = OslConfig::usiOutputPawnValue()*2.0
+	      / this->eval.captureValue(newPtypeO(alt(P),PAWN));
+	    BOOST_FOREACH(const boost::shared_ptr<SearchMonitor>& monitor,
+			  this->monitors())
+	      monitor->showFailLow(this->root_limit/200, this->recorder.allNodeCount(),
+				   this->elapsed(),static_cast<int>(result*scale),
+				   moves[0].move());
+	  }
+#endif
 	  this->setStable(false);
 	  window = window_copy;
 	}
