@@ -570,12 +570,7 @@ template <class EvalT>
 size_t osl::search::
 AlphaBeta2Parallel<EvalT>::mainCheckmateCount() const
 {
-  size_t result = master->checkmateSearcher().mainNodeCount();
-#ifndef NEW_DFPN
-  for (int i=1; i<max_threads; ++i)
-    result += checkmate[i]->mainNodeCount();
-#endif
-  return result;
+  return master->checkmateSearcher().mainNodeCount();
 }
 
 /* ------------------------------------------------------------------------- */
@@ -747,8 +742,8 @@ AlphaBeta2Tree<EvalT>::testMoveOther(int tree_id, const MoveLogProb& m, size_t i
   {
     SCOPED_LOCK(lk,parent->lock);
     w = parent->window;
-    assert(w.isConsistent() || stop_tree);
   }
+  assert(w.isConsistent() || stop_tree);
   if (stopping())
     return false;
   assert(P == m.player());
