@@ -15,6 +15,10 @@ void osl::search::SearchMonitor::showPV(int, size_t, double, int, Move, const Mo
 {
 }
 
+void osl::search::SearchMonitor::showFailLow(int, size_t, double, int, Move)
+{
+}
+
 void osl::search::SearchMonitor::rootMove(Move)
 {
 }
@@ -44,6 +48,10 @@ void osl::search::SearchMonitor::depthFinishedNormally(int)
 {
 }
 
+void osl::search::SearchMonitor::searchFinished()
+{
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
