@@ -9,6 +9,7 @@
 
 #include "osl/move_generator/legalMoves.h"
 #include "osl/checkmate/dfpnRecord.h"
+#include "osl/hash/hashRandomPair.h"
 #include "osl/oslConfig.h"
 
 #include <boost/scoped_ptr.hpp>
@@ -26,6 +27,9 @@ using namespace osl;
 using namespace osl::checkmate;
 using namespace osl::misc;
 
+unsigned int dovetailing_seed = 0;
+unsigned int dovetailing_prob = 0;
+
 bool verbose=false;
 unsigned long long total_cycles=0;
 bool show_escape_filename = false;
@@ -53,10 +57,14 @@ int main(int argc, char **argv)
   extern int optind;
 
   char c;
-  while ((c = getopt(argc, argv, "dfl:N:F:t:vh")) != EOF)
+  while ((c = getopt(argc, argv, "dfl:N:F:s:p:t:vh")) != EOF)
   {
     switch(c)
     {
+    case 's':   dovetailing_seed = static_cast<unsigned int>(atoi(optarg));
+      break;
+    case 'p':   dovetailing_prob = static_cast<unsigned int>(atoi(optarg));
+      break;
     case 'd':	debug = true;
       break;
     case 'f':	force_attack = true;
@@ -86,6 +94,8 @@ int main(int argc, char **argv)
     return 1;
   }
   OslConfig::setDfpnMaxDepth(1600);	// sufficient for microcosmos
+  if (dovetailing_prob > 0)
+    HashRandomPair::setUp(dovetailing_seed, dovetailing_prob);
   try
   {
     for (int i=0; i<argc; ++i)
