@@ -18,7 +18,7 @@ void convert(const char *filename)
   std::cout << "N+" << record.getPlayer(BLACK) << std::endl;
   std::cout << "N-" << record.getPlayer(WHITE) << std::endl;
   record.getMoves(moves, time, comment, move_comment);
-  NumEffectState state = file.getInitialState();
+  NumEffectState state(file.getInitialState());
   std::cout << state;
   for (size_t i=0; i<moves.size(); ++i) 
   {
