@@ -1,7 +1,7 @@
 /* show-ipx.cc
  */
 #include "osl/record/kisen.h"
-
+#include "osl/misc/iconvConvert.h"
 #include <iostream>
 using namespace osl;
 
@@ -10,11 +10,15 @@ int main(int argc, char **argv)
   for (int i=1; i<argc; ++i) {
     KisenIpxFile ipx(argv[i]);
     for (size_t j=0; j<ipx.size(); ++j) {
-      std::cout << ipx.getPlayer(j, BLACK) << "\t" 
-		<< ipx.getTitle(j, BLACK) << "\t"
+      if (ipx.getStartDate(j).is_special())
+	std::cout << "N/A\t";
+      else
+	std::cout << ipx.getStartDate(j).year() << "\t";
+      std::cout << IconvConvert::eucToLang(ipx.getPlayer(j, BLACK)) << "\t" 
+		<< IconvConvert::eucToLang(ipx.getTitle(j, BLACK)) << "\t"
 		<< ipx.getRating(j, BLACK) << "\t";
-      std::cout << ipx.getPlayer(j, WHITE) << "\t" 
-		<< ipx.getTitle(j, WHITE) << "\t"
+      std::cout << IconvConvert::eucToLang(ipx.getPlayer(j, WHITE)) << "\t" 
+		<< IconvConvert::eucToLang(ipx.getTitle(j, WHITE)) << "\t"
 		<< ipx.getRating(j, WHITE) << "\n";
     }
   }
