@@ -18,7 +18,7 @@ public:
   {
     osl::record::opening::WeightedBook book(osl::OslConfig::openingBook());
     osl::game_playing::DeterminateWeightTracer tracer(book, false, 1);
-    const Move m76fu(Position(7,7),Position(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m76fu(Square(7,7),Square(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
 
     for (int i=0; i<100; ++i)
     {
@@ -30,8 +30,8 @@ public:
   {
     osl::record::opening::WeightedBook book(osl::OslConfig::openingBook());
     osl::game_playing::DeterminateWeightTracer tracer(book, false, 2);
-    const Move m76fu(Position(7,7),Position(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
-    const Move m26fu(Position(2,7),Position(2,6),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m76fu(Square(7,7),Square(7,6),PAWN,PTYPE_EMPTY,false,BLACK);
+    const Move m26fu(Square(2,7),Square(2,6),PAWN,PTYPE_EMPTY,false,BLACK);
 
     for (int i=0; i<100; ++i)
     {
