@@ -1,17 +1,17 @@
+#include "osl/move_generator/addEffect8.h"
 #include "osl/move_generator/allMoves.h"
 #include "osl/move_action/store.h"
-#include "osl/move_classifier/safeMove.h"
-#include "osl/move_generator/addEffect8.h"
+#include "osl/move_classifier/classifier.h"
 #include "osl/record/record.h"
 #include "osl/record/csaRecord.h"
 #include "osl/record/csaString.h"
 #include "osl/container/pieceVector.h"
 #include "osl/container/moveVector.h"
-#include "osl/apply_move/applyMove.h"
 #include "osl/effect_util/effectUtil.h"
 #include "osl/effect_util/additionalEffect.h"
 #include "osl/oslConfig.h"
 
+#include <boost/progress.hpp>
 #include <cppunit/TestCase.h>
 #include <cppunit/extensions/HelperMacros.h>
 #include <iostream>
@@ -31,6 +31,7 @@ class AddEffect8Test : public CppUnit::TestFixture
   CPPUNIT_TEST(testShort);
   CPPUNIT_TEST(testMoveMember);
   CPPUNIT_TEST(testBug_r3527);
+  CPPUNIT_TEST(test20100117);
   CPPUNIT_TEST_SUITE_END();
 public:
   void testOne();
@@ -43,6 +44,7 @@ public:
   void testAdditional();
   void testMoveMember();
   void testBug_r3527();
+  void test20100117();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(AddEffect8Test);
@@ -70,13 +72,13 @@ void AddEffect8Test::testOne()
 			   "P-00GI00KE00FU00FU00FU00FU\n"
 			   "-\n"
 			   ).getInitialState());
-    CPPUNIT_ASSERT(mayNotGeneratedMove(state,Move(Position(7,6),Position(7,8),LANCE,PTYPE_EMPTY,false,WHITE)));
+    CPPUNIT_ASSERT(mayNotGeneratedMove(state,Move(Square(7,6),Square(7,8),LANCE,PTYPE_EMPTY,false,WHITE)));
     MoveVector moves;
     {
       move_action::Store store(moves);
-      GenerateAddEffect8::generate(state.getTurn(),state,store);
+      GenerateAddEffect8::generate(state.turn(),state,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(7,6),Position(7,8),LANCE,PTYPE_EMPTY,false,WHITE)) ||
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(7,6),Square(7,8),LANCE,PTYPE_EMPTY,false,WHITE)) ||
 		   (std::cerr << moves << std::endl,0));
   }
   {
@@ -93,13 +95,13 @@ void AddEffect8Test::testOne()
 			   "P+00GI00KE00KE00FU00FU\n"
 			   "-\n"
 			   ).getInitialState());
-    CPPUNIT_ASSERT(mayNotGeneratedMove(state,Move(Position(3,8),Position(3,9),GOLD,PTYPE_EMPTY,false,WHITE)));
+    CPPUNIT_ASSERT(mayNotGeneratedMove(state,Move(Square(3,8),Square(3,9),GOLD,PTYPE_EMPTY,false,WHITE)));
     MoveVector moves;
     {
       move_action::Store store(moves);
-      GenerateAddEffect8::generate(state.getTurn(),state,store);
+      GenerateAddEffect8::generate(state.turn(),state,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,8),Position(3,9),GOLD,PTYPE_EMPTY,false,WHITE)) ||
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,8),Square(3,9),GOLD,PTYPE_EMPTY,false,WHITE)) ||
 		   (std::cerr << moves << std::endl,0));
   }
   {
@@ -119,9 +121,9 @@ void AddEffect8Test::testOne()
     MoveVector moves;
     {
       move_action::Store store(moves);
-      GenerateAddEffect8::generate(state.getTurn(),state,store);
+      GenerateAddEffect8::generate(state.turn(),state,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(6,4),Position(6,7),LANCE,PTYPE_EMPTY,false,WHITE)) ||
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(6,4),Square(6,7),LANCE,PTYPE_EMPTY,false,WHITE)) ||
 		   (std::cerr << moves << std::endl,0));
   }
 }
@@ -136,10 +138,10 @@ void AddEffect8Test::testDropShort()
 		"P4 *  * +FU-FU *  *  *  *  *\n"
 		"P5 *  * -KE * +FU *  * +FU *\n"
 		"P6+KE *  * +FU+GI-FU *  * +FU\n"
-		"P7 *  * -UM *  *  *  *  *  *\n"
+		"P7 *  *  *  *  *  *  *  *  *\n"
 		"P8 *  *  *  *  *  *  *  *  * \n"
 		"P9 * +OU * -GI *  *  *  * -NG\n"
-		"P+00HI00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
+		"P+00HI00KA00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
 		"P-00KI00KY00FU00FU\n"
 		"P-00AL\n"
 		"+\n"
@@ -150,15 +152,46 @@ void AddEffect8Test::testDropShort()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),PAWN,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),PAWN,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,4),KNIGHT,BLACK)));
     // 王手はproduceしない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),GOLD,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),GOLD,BLACK)));
     // 二歩
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),PAWN,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),PAWN,BLACK)));
+    // 玉以外から取られる飛車は生成しない
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),ROOK,BLACK)));
+    // 玉以外から取られない角生成する
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,1),BISHOP,BLACK)));
+  }
+  {
+    SimpleState state=
+      CsaString(
+		"P1+NY+TO *  *  *  * -OU * -KY\n"
+		"P2 *  *  *  *  * -KE-KI *  * \n"
+		"P3 *  *  *  * +UM *  * -FU-FU\n"
+		"P4 *  * +FU-FU *  *  *  * -KI\n"
+		"P5 *  * -KE * +FU *  * +FU-GI\n"
+		"P6+KE *  * +FU+GI-FU+HI * +FU\n"
+		"P7 *  *  *  *  *  *  *  *  *\n"
+		"P8 *  *  *  *  *  *  *  *  * \n"
+		"P9 * +OU * -GI *  *  *  * -NG\n"
+		"P+00HI00KA00KI00KE00KY00FU00FU00FU00FU00FU00FU\n"
+		"P-00KI00KY00FU00FU\n"
+		"P-00AL\n"
+		"+\n"
+		).getInitialState();
+    NumEffectState eState(state);
+    MoveVector moves;
+    {
+      move_action::Store store(moves);
+      GenerateAddEffect8::generate(BLACK,eState,store);
+    }
+    // pinnedなら飛車角もdropする
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,1),BISHOP,BLACK)));
   }
 }
 
@@ -186,7 +219,7 @@ void AddEffect8Test::testDropLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,6),BISHOP,WHITE)) ||
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,6),BISHOP,WHITE)) ||
 		   (std::cerr << moves << std::endl,0)
 		   );
   }
@@ -213,76 +246,76 @@ void AddEffect8Test::testDropLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,2),LANCE,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,2),LANCE,BLACK)));
 
     // 飛車のただ捨て
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,3),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,5),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,5),LANCE,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,3),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,5),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,5),LANCE,BLACK)));
 
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,2),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(6,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(6,2),ROOK,BLACK)));
 
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(7,2),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(8,2),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(9,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(7,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(8,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(9,2),ROOK,BLACK)));
 
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,1),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,1),BISHOP,BLACK)));
     //
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,3),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,3),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),BISHOP,BLACK)));
 
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,3),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,3),BISHOP,BLACK)));
 
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,4),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(6,5),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(7,6),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(8,7),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(9,8),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,1),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,4),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(6,5),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(7,6),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(8,7),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(9,8),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,1),BISHOP,BLACK)));
 
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,4),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,5),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,1),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,4),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,5),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,1),BISHOP,BLACK)));
 
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,2),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(6,3),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,2),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(6,3),BISHOP,BLACK)));
 
     // direct系
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,1),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,3),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,3),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,4),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,4),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,5),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,5),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,1),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,3),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,3),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,4),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,4),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,5),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,5),LANCE,BLACK)));
     // 2つ以上は生成しない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,6),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,7),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,8),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,9),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,6),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,7),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,8),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,9),ROOK,BLACK)));
 
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,6),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,7),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,8),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,9),LANCE,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,3),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,6),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,7),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,8),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,9),LANCE,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,3),BISHOP,BLACK)));
 
 
     // 王手はproduceしない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),BISHOP,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,1),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,1),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(6,1),ROOK,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(7,1),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,1),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,1),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(6,1),ROOK,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(7,1),ROOK,BLACK)));
 
     // 盤外への利き
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,1),LANCE,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(6,2),BISHOP,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,1),LANCE,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(6,2),BISHOP,BLACK)));
   }
 }
 
@@ -311,14 +344,14 @@ void AddEffect8Test::testShort()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(3,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(1,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,4),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),PAWN,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(3,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(1,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,4),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),PAWN,BLACK)));
     // 王手はproduceしない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(4,3),KNIGHT,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),GOLD,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(4,3),KNIGHT,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),GOLD,BLACK)));
   }
   {
     SimpleState state=
@@ -343,7 +376,7 @@ void AddEffect8Test::testShort()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,4),Position(2,3),PAWN,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,4),Square(2,3),PAWN,PTYPE_EMPTY,false,BLACK)));
   }
 }
 void AddEffect8Test::testLong()
@@ -371,7 +404,7 @@ void AddEffect8Test::testLong()
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
     // 2重の追加利き
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(6,2),Position(9,2),ROOK,PTYPE_EMPTY,false,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(6,2),Square(9,2),ROOK,PTYPE_EMPTY,false,WHITE)));
   }
   {
     SimpleState state=
@@ -395,8 +428,8 @@ void AddEffect8Test::testLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
-    // openだが，直接利きを減らしている．生成しない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(9,5),Position(8,6),GOLD,PTYPE_EMPTY,false,WHITE)));
+    // open，直接利きを減らしているが，生成する．
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(9,5),Square(8,6),GOLD,PTYPE_EMPTY,false,WHITE)));
   }
   {
     SimpleState state=
@@ -421,7 +454,7 @@ void AddEffect8Test::testLong()
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
     // open
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(9,5),Position(8,6),SILVER,PTYPE_EMPTY,false,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(9,5),Square(8,6),SILVER,PTYPE_EMPTY,false,WHITE)));
   }
   {
     SimpleState state=
@@ -446,7 +479,7 @@ void AddEffect8Test::testLong()
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
     // 飛車角の追加利きは取られるところには移動しても良い
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,9),Position(6,8),BISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,9),Square(6,8),BISHOP,PTYPE_EMPTY,false,BLACK)));
   }
   {
     SimpleState state=
@@ -470,7 +503,7 @@ void AddEffect8Test::testLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,9),Position(2,7),PROOK,PTYPE_EMPTY,false,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,9),Square(2,7),PROOK,PTYPE_EMPTY,false,WHITE)));
   }
   {
     SimpleState state=
@@ -494,8 +527,8 @@ void AddEffect8Test::testLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,5),Position(6,4),BISHOP,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,5),Position(4,4),BISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,5),Square(6,4),BISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,5),Square(4,4),BISHOP,PTYPE_EMPTY,false,BLACK)));
     // 飛車角は利きのあるところには移動しても良い
   }
 
@@ -522,25 +555,25 @@ void AddEffect8Test::testLong()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,3),Position(5,2),PBISHOP,PTYPE_EMPTY,false,BLACK))||
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,3),Square(5,2),PBISHOP,PTYPE_EMPTY,false,BLACK))||
 		   (std::cerr << moves << std::endl,0)
 		   );
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(5,3),Position(4,3),PBISHOP,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(8,3),Position(8,2),PROOK,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(8,3),Position(7,2),PROOK,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(8,3),Position(9,2),PROOK,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(2,2),ROOK,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(2,2),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,5),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,4),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(4,3),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(5,3),Square(4,3),PBISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(8,3),Square(8,2),PROOK,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(8,3),Square(7,2),PROOK,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(8,3),Square(9,2),PROOK,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(2,2),ROOK,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(2,2),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,5),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,4),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(4,3),LANCE,BLACK)));
     // 王手はproduceしない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,3),Position(4,2),PBISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,3),Square(4,2),PBISHOP,PTYPE_EMPTY,false,BLACK)));
     // 盤外に利きを付ける手は生成しない
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,3),Position(6,2),PBISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,3),Square(6,2),PBISHOP,PTYPE_EMPTY,false,BLACK)));
     // 利きがblockされていることはチェックする
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(5,3),Position(4,4),PBISHOP,PTYPE_EMPTY,false,BLACK)));
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(3,4),LANCE,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(5,3),Square(4,4),PBISHOP,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(3,4),LANCE,BLACK)));
   }
 }
 void AddEffect8Test::testAdditional()
@@ -567,8 +600,8 @@ void AddEffect8Test::testAdditional()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(BLACK,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(8,5),LANCE,BLACK)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(8,6),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(8,5),LANCE,BLACK)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(8,6),LANCE,BLACK)));
   }
   {
     SimpleState state=
@@ -592,7 +625,7 @@ void AddEffect8Test::testAdditional()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(7,4),LANCE,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(7,4),LANCE,WHITE)));
   }
   {
     SimpleState state=
@@ -616,19 +649,19 @@ void AddEffect8Test::testAdditional()
       move_action::Store store(moves);
       GenerateAddEffect8::generate(WHITE,eState,store);
     }
-    CPPUNIT_ASSERT(!moves.isMember(Move(Position(7,4),LANCE,WHITE)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(7,6),LANCE,WHITE)));
-    CPPUNIT_ASSERT(moves.isMember(Move(Position(9,4),LANCE,WHITE)));
+    CPPUNIT_ASSERT(!moves.isMember(Move(Square(7,4),LANCE,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(7,6),LANCE,WHITE)));
+    CPPUNIT_ASSERT(moves.isMember(Move(Square(9,4),LANCE,WHITE)));
   }
 }
 static bool isCheckMove(NumEffectState& state,Move move){
   // 自分で動いて元のpositionに利きをつける手は含まない
-  Player pl=state.getTurn();
-  Position kingPosition=state.getKingPosition(alt(pl));
+  Player pl=state.turn();
+  Square kingSquare=state.kingSquare(alt(pl));
   NumEffectState next_state(state);
-  ApplyMoveOfTurn::doMove(next_state, move);
+  next_state.makeMove(move);
   // なるべく王手は生成したくないが，生成してしまうこともある．
-  return next_state.hasEffectBy(pl,kingPosition);
+  return next_state.hasEffectAt(pl,kingSquare);
 }
 
 /**
@@ -637,11 +670,11 @@ static bool isCheckMove(NumEffectState& state,Move move){
  */
 static bool mayNotGeneratedMove(const NumEffectState& savedState,Move move){
   NumEffectState state = savedState;
-  Player pl=state.getTurn();
-  Position kingPosition=state.getKingPosition(alt(pl));
+  Player pl=state.turn();
+  Square kingSquare=state.kingSquare(alt(pl));
   Ptype ptype=move.ptype();
   // 
-  if(move.isPromote()) return true;
+  if(move.isPromotion()) return true;
   if(move.capturePtype()!=PTYPE_EMPTY) return true;
   // 王が動いた時は生成しないことがある．
   if(ptype==KING) return true;
@@ -657,12 +690,12 @@ static bool mayNotGeneratedMove(const NumEffectState& savedState,Move move){
      ptype==LANCE &&
      ((pl==BLACK && move.to().y()==2) ||
       (pl==WHITE && move.to().y()==8))) return true;
-  ApplyMoveOfTurn::doMove(state, move);
+  state.makeMove(move);
   // なるべく王手は生成したくないが，生成してしまうこともある．
-  if(state.hasEffectBy(pl,kingPosition)) return true;
+  if(state.hasEffectAt(pl,kingSquare)) return true;
   for(int i=0;i<8;i++){
     Direction d=static_cast<Direction>(i);
-    Position pos=kingPosition+Board_Table.getOffsetForBlack(d);
+    Square pos=kingSquare+Board_Table.getOffsetForBlack(d);
     if(!pos.isOnBoard()) continue;
     if(savedState.countEffect(pl,pos)>state.countEffect(pl,pos)) continue;
     if(effect_util::AdditionalEffect::count2(savedState,pos,pl)>
@@ -671,7 +704,7 @@ static bool mayNotGeneratedMove(const NumEffectState& savedState,Move move){
       // 元々の駒が直接利きを持っていたのを間接利きに変わる例も
       // これは未対応
       if(move.from().isOnBoard() &&
-	 savedState.hasEffectByPiece(savedState.getPieceAt(move.from()),pos)){
+	 savedState.hasEffectByPiece(savedState.pieceAt(move.from()),pos)){
 	return true;
       }
       continue;
@@ -695,25 +728,25 @@ static bool mayNotGeneratedMove(const NumEffectState& savedState,Move move){
 static bool isAddEffect8Move(const NumEffectState& state_org,Move move){
   // 自分で動いて元のpositionに利きをつける手は含まない
   NumEffectState state = state_org;
-  Player pl=state.getTurn();
-  Position kingPosition=state.getKingPosition(alt(pl));
+  Player pl=state.turn();
+  Square kingSquare=state.kingSquare(alt(pl));
   NumEffectState savedState(state);
   Ptype ptype=move.ptype();
-  if(move.isPromote()) return false;
+  if(move.isPromotion()) return false;
   if(move.capturePtype()!=PTYPE_EMPTY) return false;
   if(isCheckMove(state,move)) return false;
   // 飛車角は相手の利きのあるところにはdropしない
   if(!move.from().isOnBoard() && (ptype==ROOK || ptype==BISHOP) &&
-     state.hasEffectBy(alt(pl),move.to())) return false;
-  ApplyMoveOfTurn::doMove(state, move);
+     state.hasEffectByNotPinnedAndKing(alt(pl),move.to())) return false;
+  state.makeMove(move);
   for(int i=0;i<8;i++){
     Direction d=static_cast<Direction>(i);
-    Position pos=kingPosition+Board_Table.getOffsetForBlack(d);
+    Square pos=kingSquare+Board_Table.getOffsetForBlack(d);
     if(!pos.isOnBoard()){
       PtypeO ptypeO=newPtypeO(pl,ptype);
       // 盤外であっても短い利きが増えたらOK
-      Position from=move.from();
-      Position to=move.to();
+      Square from=move.from();
+      Square to=move.to();
       if(move.from().isOnBoard() &&
 	 (abs(from.x()-pos.x())>1 ||
 	  abs(from.y()-pos.y())>1 ||
@@ -727,18 +760,23 @@ static bool isAddEffect8Move(const NumEffectState& state_org,Move move){
       }
       continue;
     }
-    if(state.hasEffectBy(pl,pos) &&
+    if(state.hasEffectAt(pl,pos) &&
        (effect_util::AdditionalEffect::count2(savedState,pos,pl)<
 	effect_util::AdditionalEffect::count2(state,pos,pl))){
       return true;
     }
+    if(state.hasEffectAt(pl,pos) &&
+       (effect_util::AdditionalEffect::count(savedState,pl,pos)<
+	effect_util::AdditionalEffect::count(state,pl,pos))){
+      return true;
+    }
     for(int num=0;num<40;num++){
-      Piece p=state.getPieceOf(num);
+      Piece p=state.pieceOf(num);
       if(p.ptype()==KING) continue;
       if(p.isOnBoardByOwner(pl) &&
 	 state.hasEffectByPiece(p,pos)){
-	if(!savedState.hasEffectByPiece(savedState.getPieceOf(num),pos) &&
-	   ((p.position()!=move.to() && move.to() != pos)||
+	if(!savedState.hasEffectByPiece(savedState.pieceOf(num),pos) &&
+	   ((p.square()!=move.to() && move.to() != pos)||
 	    !move.from().isOnBoard() ||
 	    !(ptype==ROOK || ptype==BISHOP || ptype==PAWN) ||
 	    !(move.from().canPromote(pl) || move.to().canPromote(pl)))){
@@ -747,7 +785,7 @@ static bool isAddEffect8Move(const NumEffectState& state_org,Move move){
 	}
 	// PROOKが斜めに動いて斜めに利きをつける場合は
 	// 元々長い利きがある場合もあるが，常にtrueにする．
-	if(p.position()==move.to() && ptype==PROOK && 
+	if(p.square()==move.to() && ptype==PROOK && 
 	   abs(move.from().x()-move.to().x())==1 &&
 	   abs(move.from().y()-move.to().y())==1 &&
 	   abs(move.to().x()-pos.x())==1 &&
@@ -779,7 +817,7 @@ void AddEffect8Test::testIsAddEffect8()
 "+\n"
 		).getInitialState();
     NumEffectState eState(state);
-    CPPUNIT_ASSERT(!isAddEffect8Move(eState,Move(Position(5,1),Position(4,2),PROOK,PTYPE_EMPTY,false,BLACK)));
+    CPPUNIT_ASSERT(isAddEffect8Move(eState,Move(Square(5,1),Square(4,2),PROOK,PTYPE_EMPTY,false,BLACK)));
   }
   {
     SimpleState state=
@@ -798,7 +836,7 @@ void AddEffect8Test::testIsAddEffect8()
 		"+\n"
 		).getInitialState();
     NumEffectState eState(state);
-    //    CPPUNIT_ASSERT(!isAddEffect8Move(eState,Move(Position(3,4),Position(3,3),PAWN,PTYPE_EMPTY,false,BLACK)));
+    //    CPPUNIT_ASSERT(!isAddEffect8Move(eState,Move(Square(3,4),Square(3,3),PAWN,PTYPE_EMPTY,false,BLACK)));
   }
 }
 
@@ -807,23 +845,23 @@ static bool isAddEffect8Drop(const NumEffectState& state_org,Move move){
   // 自分で動いて元のpositionに利きをつける手は含まない
   if(!move.isDrop()) return false;
   NumEffectState state = state_org;
-  Player pl=state.getTurn();
-  Position kingPosition=state.getKingPosition(alt(pl));
+  Player pl=state.turn();
+  Square kingSquare=state.kingSquare(alt(pl));
   NumEffectState savedState(state);
-  ApplyMoveOfTurn::doMove(state, move);
-  if(state.hasEffectBy(pl,kingPosition)) return false;
+  state.makeMove(move);
+  if(state.hasEffectAt(pl,kingSquare)) return false;
   // ただ捨ての飛車角
   if(!move.from().isOnBoard() && 
      (move.ptype()==ROOK || move.ptype()==BISHOP) &&
-     state.hasEffectBy(alt(pl),move.to())) return false;
+     state.hasEffectByNotPinnedAndKing(alt(pl),move.to())) return false;
   for(int i=0;i<8;i++){
     Direction d=static_cast<Direction>(i);
-    Position pos=kingPosition+Board_Table.getOffsetForBlack(d);
+    Square pos=kingSquare+Board_Table.getOffsetForBlack(d);
     if(!pos.isOnBoard()) continue;
     if(effect_util::AdditionalEffect::count2(savedState,pos,pl)<
        effect_util::AdditionalEffect::count2(state,pos,pl)) return true;
     for(int num=0;num<40;num++){
-      Piece p=state.getPieceOf(num);
+      Piece p=state.pieceOf(num);
       if(p.ptype()==KING) continue;
       if(p.isOnBoardByOwner(pl) &&
 	 state.hasEffectByPiece(p,pos) &&
@@ -846,15 +884,15 @@ static void testDropFile(const std::string& fileName){
       {
 	Store store(allMoves);
 	AllMoves<Store>::
-	  generate(state.getTurn(),state,store);
+	  generate(state.turn(),state,store);
       }
 	  // 次の1行はaddEffect.hのバグの範囲を突き止めるためのテスト
-	  //	if(state.hasEffectBy(state.getTurn(),pos)) continue;
+	  //	if(state.hasEffectAt(state.turn(),pos)) continue;
       MoveVector effectMoves;
       {
 	Store storeEffect(effectMoves);
 	GenerateAddEffect8::
-	  generate(state.getTurn(),state,storeEffect);
+	  generate(state.turn(),state,storeEffect);
       }
       
       size_t count1=0;
@@ -885,25 +923,25 @@ static void testDropFile(const std::string& fileName){
       //      CPPUNIT_ASSERT(count == count1);
     }
     Move move=moves[i];
-    ApplyMoveOfTurn::doMove(state, move);
+    state.makeMove(move);
   }
 }
 
 void AddEffect8Test::testDropMember(){
-  extern bool isShortTest;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
   CPPUNIT_ASSERT(ifs);
   int i=0;
-  int count=20;
-  if (isShortTest) 
+  int count=100;
+  if (OslConfig::inUnitTestShort()) 
     count=2;
-  std::string fileName;
-  while((ifs >> fileName) && ++i<count){
-    if(fileName == "") 
-      break;
-    if (! isShortTest)
-      std::cerr << fileName << " ";
-    testDropFile(OslConfig::testCsaFile(fileName));
+  std::string filename;
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong())
+    progress.reset(new boost::progress_display(count, std::cerr));
+  while((ifs >> filename) && filename != "" && ++i<count){
+    if (progress)
+      ++(*progress);
+    testDropFile(OslConfig::testCsaFile(filename));
   }
 }
 
@@ -918,21 +956,21 @@ static void testMoveFile(const std::string& fileName){
       {
 	Store store(allMoves);
 	AllMoves<Store>::
-	  generate(state.getTurn(),state,store);
+	  generate(state.turn(),state,store);
       }
 	  // 次の1行はaddEffect.hのバグの範囲を突き止めるためのテスト
-	  //	if(state.hasEffectBy(state.getTurn(),pos)) continue;
+	  //	if(state.hasEffectAt(state.turn(),pos)) continue;
       MoveVector effectMoves;
       {
 	Store storeEffect(effectMoves);
 	GenerateAddEffect8::
-	  generate(state.getTurn(),state,storeEffect);
+	  generate(state.turn(),state,storeEffect);
       }
       
       for(size_t j=0;j<effectMoves.size();j++){
 	CPPUNIT_ASSERT(state.isValidMove(effectMoves[j],true) ||
 		       (std::cerr << std::endl << state << std::endl << effectMoves[j] << std::endl,0));
-	CPPUNIT_ASSERT(isSafeMove(state,effectMoves[j]) ||
+	CPPUNIT_ASSERT(Classifier::isSafeMove(state,effectMoves[j]) ||
 		       (std::cerr << std::endl << state << std::endl << effectMoves[j] << std::endl,0));
 	if(!isAddEffect8Move(state,effectMoves[j]) &&
 	   !isCheckMove(state,effectMoves[j])){
@@ -949,25 +987,25 @@ static void testMoveFile(const std::string& fileName){
       }
     }
     Move move=moves[i];
-    ApplyMoveOfTurn::doMove(state, move);
+    state.makeMove(move);
   }
 }
 
 void AddEffect8Test::testMoveMember(){
-  extern bool isShortTest;
   std::ifstream ifs(OslConfig::testCsaFile("FILES"));
   CPPUNIT_ASSERT(ifs);
   int i=0;
   int count=200;
-  if (isShortTest) 
+  if (OslConfig::inUnitTestShort()) 
     count=2;
-  std::string fileName;
-  while((ifs >> fileName) && ++i<count){
-    if(fileName == "") 
-      break;
-    if (! isShortTest)
-      std::cerr << fileName << " ";
-    testMoveFile(OslConfig::testCsaFile(fileName));
+  boost::scoped_ptr<boost::progress_display> progress;
+  if (OslConfig::inUnitTestLong())
+    progress.reset(new boost::progress_display(count, std::cerr));
+  std::string filename;
+  while((ifs >> filename) && filename != "" && ++i<count){
+    if (progress)
+      ++(*progress);
+    testMoveFile(OslConfig::testCsaFile(filename));
   }
 }
 
@@ -994,6 +1032,130 @@ void AddEffect8Test::testBug_r3527()
   CPPUNIT_ASSERT(! moves.empty());
 }
 
+void AddEffect8Test::test20100117()
+{
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY *  *  *  * -KI *  * -KY\n"
+			   "P2 *  *  *  * -KI *  *  *  * \n"
+			   "P3-FU *  *  *  * -FU * -FU * \n"
+			   "P4 *  *  *  *  *  * -FU * -FU\n"
+			   "P5 *  *  * +FU * +KE *  *  * \n"
+			   "P6 * -OU *  * +GI+FU *  * +FU\n"
+			   "P7+FU *  *  * +KA * +FU+FU * \n"
+			   "P8+GI-UM *  * +KI * +GI * +OU\n"
+			   "P9+KY * +FU *  *  *  * +KE+KY\n"
+			   "P+00GI00FU00FU\n"
+			   "P-00HI00HI00KI00KE00KE00FU00FU00FU00FU\n"
+			   "+\n").getInitialState());
+    MoveVector moves;
+    {
+      Store store(moves);
+      move_generator::AddEffect8<BLACK>::generate(state, store);
+    }
+    Move m89gi(Square(9,8), Square(8,9), SILVER, PTYPE_EMPTY, false, BLACK);
+    CPPUNIT_ASSERT(moves.isMember(m89gi)
+		   || mayNotGeneratedMove(state,m89gi)
+		   || ! isAddEffect8Move(state,m89gi));
+  }
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY *  *  *  * -KI *  * -KY\n"
+			   "P2 *  *  *  * -KI *  *  *  * \n"
+			   "P3-FU *  *  *  * -FU * -FU * \n"
+			   "P4 *  *  *  *  *  * -FU * -FU\n"
+			   "P5+FU *  * +FU * +KE *  *  * \n"
+			   "P6+KE-OU *  * +GI+FU *  * +FU\n"
+			   "P7 *  *  *  * +GI * +FU+FU * \n"
+			   "P8 * -UM *  * +KI * +GI * +OU\n"
+			   "P9+KY * +FU *  *  *  * +KA+KY\n"
+			   "P+00GI00FU00FU\n"
+			   "P-00HI00HI00KI00KE00KE00FU00FU00FU00FU\n"
+			   "+\n").getInitialState());
+    MoveVector moves;
+    {
+      Store store(moves);
+      move_generator::AddEffect8<BLACK>::generate(state, store);
+    }
+    Move m84ke(Square(9,6), Square(8,4), KNIGHT, PTYPE_EMPTY, false, BLACK);
+    CPPUNIT_ASSERT(moves.isMember(m84ke)
+		   || mayNotGeneratedMove(state, m84ke)
+		   ||! isAddEffect8Move(state, m84ke));
+  }
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY *  *  *  * -KI *  * -KY\n"
+			   "P2 *  *  *  * -KI *  *  *  * \n"
+			   "P3-FU *  *  *  * -FU * -FU * \n"
+			   "P4 *  *  *  *  *  * -FU * -FU\n"
+			   "P5+FU *  * +FU * +KE *  *  * \n"
+			   "P6+KA-OU *  * +GI+FU *  * +FU\n"
+			   "P7 *  *  *  * +GI * +FU+FU * \n"
+			   "P8 * -UM *  * +KI * +GI * +OU\n"
+			   "P9+KY * +FU *  *  *  * +KE+KY\n"
+			   "P+00GI00FU00FU\n"
+			   "P-00HI00HI00KI00KE00KE00FU00FU00FU00FU\n"
+			   "+\n").getInitialState());
+    MoveVector moves;
+    {
+      Store store(moves);
+      move_generator::AddEffect8<BLACK>::generate(state, store);
+    }
+    Move m69ka(Square(9,6), Square(6,9), BISHOP, PTYPE_EMPTY, false, BLACK);
+    CPPUNIT_ASSERT(moves.isMember(m69ka)
+		   || mayNotGeneratedMove(state, m69ka)
+		   ||! isAddEffect8Move(state, m69ka));
+  }
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY *  *  *  * -KI *  * -KY\n"
+			   "P2 *  *  *  * -KI *  *  *  * \n"
+			   "P3-FU *  *  *  * -FU * -FU * \n"
+			   "P4 *  *  *  *  *  * -FU * -FU\n"
+			   "P5 *  *  * +FU * +KE *  *  * \n"
+			   "P6 * -OU *  * +GI+FU *  * +FU\n"
+			   "P7+FU *  *  * +GI * +FU+FU * \n"
+			   "P8+KA-UM *  * +KI * +GI * +OU\n"
+			   "P9+KY * +FU *  *  *  * +KE+KY\n"
+			   "P+00GI00FU00FU\n"
+			   "P-00HI00HI00KI00KE00KE00FU00FU00FU00FU\n"
+			   "+\n").getInitialState());
+    MoveVector moves;
+    {
+      Store store(moves);
+      move_generator::AddEffect8<BLACK>::generate(state, store);
+    }
+    Move m89ka(Square(9,8), Square(8,9), BISHOP, PTYPE_EMPTY, false, BLACK);
+    CPPUNIT_ASSERT(moves.isMember(m89ka)
+		   || mayNotGeneratedMove(state,m89ka)
+		   || ! isAddEffect8Move(state,m89ka));
+  }
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY * -OU * +GI *  *  * -KY\n"
+			   "P2 *  *  * -HI *  *  * +TO * \n"
+			   "P3-KE *  * -KI-FU+KA *  * -FU\n"
+			   "P4-FU+OU * -FU *  *  * +HI * \n"
+			   "P5 *  *  * -KE *  *  *  *  * \n"
+			   "P6+FU * +FU * +FU+FU *  *  * \n"
+			   "P7 *  * +KA+FU *  *  *  * +FU\n"
+			   "P8-GI *  *  * +KI *  *  *  * \n"
+			   "P9 * -TO * +KI *  *  * +KE+KY\n"
+			   "P+00KI00GI00KE00KY00FU00FU00FU00FU00FU00FU\n"
+			   "P-00GI\n"
+			   "-\n").getInitialState());
+    MoveVector moves;
+    {
+      Store store(moves);
+      move_generator::AddEffect8<WHITE>::generate(state, store);
+    }
+    Move m85ke(Square(9,3), Square(8,5), KNIGHT, PTYPE_EMPTY, false, WHITE);
+    CPPUNIT_ASSERT(moves.isMember(m85ke)
+		   || mayNotGeneratedMove(state, m85ke)
+		   ||! isAddEffect8Move(state, m85ke));
+  }
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
