@@ -92,6 +92,22 @@ void CsaTest::setUp(){
 }
 
 void CsaTest::testShow(){
+  vector<Move> ms;
+  NumEffectState s;
+
+  CPPUNIT_ASSERT_EQUAL(std::string(""),
+                       csa::show(&*ms.begin(), &*ms.end()));
+
+  ms.push_back(csa::strToMove("+7776FU", s));
+  s.makeMove(ms.back());
+  CPPUNIT_ASSERT_EQUAL(std::string("+7776FU"),
+                       csa::show(&*ms.begin(), &*ms.end()));
+
+  ms.push_back(csa::strToMove("-3334FU", s));
+  s.makeMove(ms.back());
+
+  CPPUNIT_ASSERT_EQUAL(std::string("+7776FU-3334FU"),
+                       csa::show(&*ms.begin(), &*ms.end()));
 }
 
 void CsaTest::testLoad(){
