@@ -67,6 +67,7 @@ class EffectTest : public CppUnit::TestFixture
   CPPUNIT_TEST(testFindCheapThreat);
   CPPUNIT_TEST(testFindThreatenedPiece);
   CPPUNIT_TEST(testWasCheckEvasion);
+  CPPUNIT_TEST(testCheckShadow);
   CPPUNIT_TEST_SUITE_END();
 private:
   osl::NumEffectState state;
@@ -109,6 +110,7 @@ public:
   void testFindCheapThreat();
   void testFindThreatenedPiece();
   void testWasCheckEvasion();
+  void testCheckShadow();
 };
 
 
@@ -1338,6 +1340,44 @@ void EffectTest::testWasCheckEvasion()
   }
 }
 
+void EffectTest::testCheckShadow()
+{
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY-KE-GI-KI-OU-KI-GI-KE-KY\n"
+			   "P2 * -HI *  *  *  *  * -KA * \n"
+			   "P3-FU-FU-FU-FU-FU-FU-FU-FU-FU\n"
+			   "P4 *  *  *  *  *  *  *  *  * \n"
+			   "P5 *  *  *  *  *  *  *  *  * \n"
+			   "P6 *  *  *  *  *  *  *  *  * \n"
+			   "P7+FU+FU+FU+FU+FU+FU+FU+FU+FU\n"
+			   "P8 * +KA *  *  *  *  * +HI * \n"
+			   "P9+KY+KE+GI+KI+OU+KI+GI+KE+KY\n"
+			   "+\n").getInitialState()); 
+    CPPUNIT_ASSERT(state.checkShadow(BLACK).none());
+    CPPUNIT_ASSERT(state.checkShadow(WHITE).none());
+  }
+  {
+    NumEffectState state(CsaString(
+			   "P1-KY-KE-GI-KI-OU-KI-GI-KE-KY\n"
+			   "P2 * -HI *  *  *  *  *  *  * \n"
+			   "P3-FU-FU-FU-FU+TO-FU-FU-FU-FU\n"
+			   "P4 *  *  *  *  *  *  *  *  * \n"
+			   "P5 *  *  *  *  *  *  *  * -KA\n"
+			   "P6 *  *  *  * +KY *  *  *  * \n"
+			   "P7+FU+FU+FU+FU+FU+FU-TO+FU+FU\n"
+			   "P8 * +KA *  *  *  *  * +HI * \n"
+			   "P9+KY+KE+GI+KI+OU+KI+GI+KE * \n"
+			   "+\n").getInitialState()); 
+    PieceMask bs=state.checkShadow(BLACK), ws=state.checkShadow(WHITE);
+    CPPUNIT_ASSERT_EQUAL(1, bs.countBit());
+    CPPUNIT_ASSERT_EQUAL(1, ws.countBit());
+
+    CPPUNIT_ASSERT_EQUAL(state[Square(5,3)], state.pieceOf(bs.takeOneBit()));
+    CPPUNIT_ASSERT_EQUAL(state[Square(3,7)], state.pieceOf(ws.takeOneBit()));
+  }
+}
+
 // ;;; Local Variables:
 // ;;; mode:c++
 // ;;; c-basic-offset:2
